@@ -23,9 +23,9 @@ boto3:
 
 LOG_LEVEL = os.getenv("DJSCIOPS_LOG_LEVEL", "info")
 
-DEFAULT_THRESHOLD = 1024 * 25
-DEFAULT_CONCURRENCY = 10
-DEFAULT_CHUNKSIZE = 1024 * 25
+DEFAULT_THRESHOLD = 64 * 1024**2  # 64 MiB
+DEFAULT_CONCURRENCY = 100
+DEFAULT_CHUNKSIZE = 64 * 1024**2  # 64 MiB
 DEFAULT_THREAD_USE = True
 
 
